"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dropdown = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_reanimated_1 = require("react-native-reanimated");
const tiny_invariant_1 = __importDefault(require("tiny-invariant"));
const Button_1 = require("@procyon/components/Button");
const ButtonGroup_1 = require("@procyon/components/ButtonGroup");
const context_1 = require("@procyon/components/Modal/context");
const ChevronDown_1 = require("@procyon/icons/ChevronDown");
const ChevronUp_1 = require("@procyon/icons/ChevronUp");
const Theme_1 = require("@procyon/styles/Theme");
const debounce_1 = require("@procyon/utils/debounce");
const Dropdown = ({ Buttons, MainButton, size = 'md', name, }) => {
    const { theme } = (0, Theme_1.useTheme)();
    const viewRef = (0, react_native_reanimated_1.useAnimatedRef)();
    const [openModal, closeModal, { opened }] = (0, context_1.useModal)(name, {
        Component: ({ rootStyle }) => {
            return (react_1.default.createElement(react_native_1.View, { style: [rootStyle] }, Buttons && (react_1.default.createElement(Buttons, Object.assign({}, (size ? { size } : {}), { fullWidth: true,
                style: {
                    container: {
                        marginVertical: 3,
                    },
                }, onClick: (0, debounce_1.debounceAfter)(() => handleClose(), 100) })))));
        },
    });
    const handleClose = () => {
        closeModal();
    };
    const handleOpenButtons = () => {
        if (opened.includes(name)) {
            closeModal();
            return;
        }
        (0, react_native_reanimated_1.runOnUI)(() => {
            if (!(viewRef === null || viewRef === void 0 ? void 0 : viewRef.current)) {
                (0, tiny_invariant_1.default)('Unable to measure element for obtain position!');
                return null;
            }
            const layout = (0, react_native_reanimated_1.measure)(viewRef);
            (0, react_native_reanimated_1.runOnJS)(openModal)({
                props: {
                    rootStyle: Object.assign(Object.assign(Object.assign(Object.assign({ position: 'absolute' }, (!!(layout === null || layout === void 0 ? void 0 : layout.width) && { width: layout.width })), (!!(layout === null || layout === void 0 ? void 0 : layout.pageY) && {
                        top: layout.pageY + theme.spacing[size] * 2 + theme.fontSize[size] * 2,
                    })), (!!(layout === null || layout === void 0 ? void 0 : layout.pageX) && { left: layout.pageX })), { zIndex: 7 }),
                },
                style: {
                    overflow: {
                        backgroundColor: 'transparent',
                    },
                },
            });
        })();
    };
    return (react_1.default.createElement(ButtonGroup_1.ButtonGroup, { ref: viewRef },
        MainButton,
        Buttons && (react_1.default.createElement(Button_1.Button, Object.assign({ style: { container: { minWidth: 40, maxWidth: 50 } }, onClick: () => handleOpenButtons() }, (size ? { size } : {})), opened.includes(name) ? react_1.default.createElement(ChevronUp_1.ChevronUpIcon, null) : react_1.default.createElement(ChevronDown_1.ChevronDownIcon, null)))));
};
exports.Dropdown = Dropdown;
