import React, { FC } from 'react';
import { GestureResponderEvent, StyleProp, ViewStyle } from 'react-native';
import { ListItemProps } from '@procyon/components/ListItem';
export type ListData = {
    id: number | string;
    label?: string;
};
type CommonProps<Items extends ListData[]> = {
    Item?: FC<ListItemProps<Items[0] & ListData, 'view' | undefined>>;
    color?: 'primary' | 'secondary' | 'positive' | 'negative';
    compact?: boolean;
    data?: Items;
    getLabel?: (items: Items[0]) => string;
    selected?: ListData['id'];
    size?: 'sm' | 'md' | 'lg' | 'xl';
    style?: {
        container?: StyleProp<ViewStyle>;
        list?: StyleProp<ViewStyle>;
    };
};
export type OnClickProp = {
    onClick: (event: GestureResponderEvent, id: ListData['id']) => void;
};
export type InteractiveMode<Items extends ListData[]> = {
    mode?: undefined;
} & OnClickProp & CommonProps<Items>;
export type ViewMode<Items extends ListData[]> = {
    mode: 'view';
} & Partial<OnClickProp> & CommonProps<Items>;
export type ListProps<Items extends ListData[]> = InteractiveMode<Items> | ViewMode<Items>;
export declare const List: <Items extends ListData[]>({ style, data, selected, getLabel, Item, mode, ...props }: ListProps<Items>) => React.JSX.Element;
export {};
