import React, { ReactNode } from 'react';
import { GestureResponderEvent, StyleProp, Text, View, ViewProps } from 'react-native';
import { ListData } from '@procyon/components/List';
type CommonProps<Item extends ListData> = {
    children: ReactNode;
    color?: 'primary' | 'secondary' | 'positive' | 'negative';
    compact?: boolean;
    item: Item;
    selected?: boolean;
    size?: 'sm' | 'md' | 'lg' | 'xl';
    style?: {
        container?: StyleProp<ViewProps>;
    };
};
type OnClick = (event: GestureResponderEvent, id: ListData['id']) => void;
type InteractiveMode<Item extends ListData, Mode = undefined> = {
    mode?: Mode;
    onClick: OnClick;
} & CommonProps<Item>;
type ViewMode<Item extends ListData, Mode = 'view'> = {
    mode: Mode;
    onClick?: OnClick;
} & CommonProps<Item>;
export type ListItemProps<Item extends ListData, Mode extends 'view' | undefined> = InteractiveMode<Item, Mode> | ViewMode<Item, Mode>;
export declare const ListItem: <Item extends ListData, Mode extends "view" | undefined>({ style, size, mode, onClick, children, color, selected, item, }: ListItemProps<Item, Mode>) => React.JSX.Element;
export declare const ListItemView: import("@emotion/native").StyledComponent<ViewProps & {
    theme?: import("@emotion/react").Theme | undefined;
    as?: React.ElementType<any, keyof React.JSX.IntrinsicElements> | undefined;
}, {}, {
    ref?: React.Ref<View> | undefined;
}>;
export declare const ListItemText: import("@emotion/native").StyledComponent<import("react-native").TextProps & {
    theme?: import("@emotion/react").Theme | undefined;
    as?: React.ElementType<any, keyof React.JSX.IntrinsicElements> | undefined;
} & {
    color?: ListItemProps<any, any>['color'];
    hover?: boolean | undefined;
    selected?: ListItemProps<any, any>['selected'];
    size?: ListItemProps<any, any>['size'];
}, {}, {
    ref?: React.Ref<Text> | undefined;
}>;
export {};
