"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Puzzle = void 0;
const react_1 = __importStar(require("react"));
const native_1 = __importDefault(require("@emotion/native"));
const react_native_1 = require("react-native");
const react_native_gesture_handler_1 = require("react-native-gesture-handler");
const react_native_reanimated_1 = __importStar(require("react-native-reanimated"));
const Label_1 = require("@procyon/components/Label");
const tolgee_1 = require("@procyon/localization/tolgee");
function clamp(val, min, max) {
    return Math.min(Math.max(val, min), max);
}
function getRandomPosition(min, max) {
    min = Math.ceil(min);
    max = Math.floor(max);
    return Math.floor(Math.random() * (max - min + 1)) + min;
}
const Puzzle = ({ onVerified, containerDimension = {
    width: 200,
    height: 100,
}, ballDimension = {
    width: 20,
    height: 20,
}, holeDimension = {
    width: 30,
    height: 30,
}, }) => {
    const [verified, setVerified] = (0, react_1.useState)(false);
    const { t } = (0, tolgee_1.useTranslate)();
    const playgroundWidth = containerDimension.width / 2;
    const translationX = (0, react_native_reanimated_1.useSharedValue)(getRandomPosition(0, playgroundWidth - 20));
    const translationY = (0, react_native_reanimated_1.useSharedValue)(getRandomPosition(0, containerDimension.height - 20));
    const prevTranslationX = (0, react_native_reanimated_1.useSharedValue)(0);
    const prevTranslationY = (0, react_native_reanimated_1.useSharedValue)(0);
    const [holeX, holeY] = (0, react_1.useMemo)(() => {
        return [
            getRandomPosition(playgroundWidth, containerDimension.width - 30),
            getRandomPosition(0, containerDimension.height - 30),
        ];
    }, []);
    const animatedStyles = (0, react_native_reanimated_1.useAnimatedStyle)(() => ({
        transform: [{ translateX: translationX.value }, { translateY: translationY.value }],
    }));
    const panGesture = react_native_gesture_handler_1.Gesture.Pan()
        .enabled(!verified)
        .minDistance(0)
        .onStart(() => {
        prevTranslationX.value = translationX.value;
        prevTranslationY.value = translationY.value;
    })
        .onUpdate((event) => {
        const maxTranslateX = containerDimension.width - ballDimension.width;
        const maxTranslateY = containerDimension.height - ballDimension.height;
        translationX.value = clamp(prevTranslationX.value + event.translationX, 0, maxTranslateX);
        translationY.value = clamp(prevTranslationY.value + event.translationY, 0, maxTranslateY);
    })
        .onFinalize(() => {
        const roundHoleX = Math.floor(holeX);
        const roundTranslationX = Math.floor(translationX.value);
        const roundHoleY = Math.floor(holeY);
        const roundTranslationY = Math.floor(translationY.value);
        if (roundTranslationX >= roundHoleX &&
            roundTranslationX <= roundHoleX + 10 &&
            roundTranslationY >= roundHoleY &&
            roundTranslationY <= roundHoleY + 10) {
            setVerified(true);
            onVerified();
        }
    });
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(Label_1.Label, null, t('procyon.puzzle.manual')),
        react_1.default.createElement(react_native_gesture_handler_1.GestureDetector, { gesture: panGesture },
            react_1.default.createElement(PuzzleContainer, { style: [containerDimension] },
                react_1.default.createElement(PuzzleHole, { verified: verified, x: holeX, y: holeY, style: [holeDimension] }),
                !verified && react_1.default.createElement(PuzzleBall, { style: [ballDimension, animatedStyles] })))));
};
exports.Puzzle = Puzzle;
const PuzzleContainer = (0, native_1.default)(react_native_1.View)(({ theme }) => {
    return {
        position: 'relative',
        borderWidth: 1,
        borderColor: theme.palette.secondary.main,
        borderRadius: theme.rounded.small,
    };
});
const PuzzleBall = (0, native_1.default)(react_native_reanimated_1.default.View)(({ theme }) => {
    return Object.assign(Object.assign({ borderRadius: theme.rounded.full, position: 'absolute' }, { cursor: 'move' }), { borderWidth: 1, borderColor: theme.palette.primary.dark, backgroundColor: theme.palette.primary.light });
});
const PuzzleHole = (0, native_1.default)(react_native_reanimated_1.default.View)(({ theme, x, y, verified }) => {
    return Object.assign({ borderRadius: theme.rounded.full, borderWidth: 2, borderStyle: 'dashed', borderColor: theme.palette.negative.main, transform: [{ translateX: x }, { translateY: y }] }, (verified && {
        backgroundColor: theme.palette.positive.main,
        borderColor: theme.palette.primary.dark,
        borderStyle: 'solid',
    }));
});
