"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextField = void 0;
const react_1 = __importDefault(require("react"));
const native_1 = __importDefault(require("@emotion/native"));
const react_native_1 = require("react-native");
const values_js_1 = __importDefault(require("values.js"));
const FieldMessage_1 = require("@procyon/components/FieldMessage");
const Theme_1 = require("@procyon/styles/Theme");
const useMediaQuery_1 = require("@procyon/styles/useMediaQuery");
const Label_1 = require("./Label");
const Skeleton_1 = require("./Skeleton");
const TextField = (props) => {
    const { Input = TextFieldInput, mode = 'text', onClick, onFocus, onBlur, onChange, disabled = false, name, label, color = 'secondary', autoFocus, mask, placeholder, multiline, LeftIcon, RightIcon, leftText, rightText, message, style, readonly, size = 'md', labelSize, secret, loading, fullWidth, rows, } = props;
    const mq = (0, useMediaQuery_1.useMediaQuery)();
    const { theme } = (0, Theme_1.useTheme)();
    const applyMask = (val) => {
        if (mask && val) {
            mask.resolve(val);
            return mask.value;
        }
        return val;
    };
    const value = applyMask(props.value);
    const handleClick = (e) => {
        onClick === null || onClick === void 0 ? void 0 : onClick(e);
    };
    const handleFocus = (e) => {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(e, e.nativeEvent.text);
    };
    const handleBlur = (e) => {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(e, e.nativeEvent.text);
    };
    const handleChange = (e) => {
        const value = e.nativeEvent.text;
        const maskedValue = applyMask(value);
        if (onChange) {
            onChange(e, maskedValue);
        }
    };
    return (react_1.default.createElement(react_native_1.View, { style: [
            {
                width: fullWidth || (fullWidth === undefined && mq === 'xs') ? '100%' : 'auto',
            },
            style === null || style === void 0 ? void 0 : style.container,
        ], "aria-label": "textfield" },
        react_1.default.createElement(Label_1.Label, { disabled: disabled, size: labelSize }, label),
        react_1.default.createElement(Skeleton_1.Skeleton, { active: loading || false, layout: [{ key: '1', height: 40 }] },
            react_1.default.createElement(TextFieldWrapper, { color: color, disabled: disabled, style: [style === null || style === void 0 ? void 0 : style.wrapper] },
                LeftIcon && (react_1.default.createElement(TextFieldIconContainer, null,
                    react_1.default.createElement(LeftIcon, { style: [style === null || style === void 0 ? void 0 : style.icon], color: theme.palette.secondary.dark }))),
                leftText && (react_1.default.createElement(TextFieldIconContainer, null,
                    react_1.default.createElement(TextFieldText, { color: color, size: size }, leftText))),
                react_1.default.createElement(react_native_1.Pressable, { onPress: (e) => handleClick(e), style: [
                        {
                            flex: 1,
                            justifyContent: 'center',
                        },
                    ] },
                    react_1.default.createElement(Input, { size: size, style: [style === null || style === void 0 ? void 0 : style.input], id: name, disabled: disabled, secureTextEntry: secret, inputMode: mode, onFocus: handleFocus, onBlur: handleBlur, onChange: handleChange, autoFocus: autoFocus, readOnly: readonly || disabled, value: value !== null && value !== void 0 ? value : '', multiline: multiline, rows: rows, placeholder: placeholder, placeholderTextColor: new values_js_1.default(theme.palette.text.light)
                            .shade(30)
                            .rgbString(), autoComplete: "off" })),
                RightIcon && (react_1.default.createElement(TextFieldIconContainer, null,
                    react_1.default.createElement(RightIcon, { style: [style === null || style === void 0 ? void 0 : style.icon], color: theme.palette.secondary.dark }))),
                rightText && (react_1.default.createElement(TextFieldIconContainer, null,
                    react_1.default.createElement(TextFieldText, { color: color, size: size }, rightText))))),
        react_1.default.createElement(FieldMessage_1.FieldMessage, { message: message, color: color, size: size })));
};
exports.TextField = TextField;
const TextFieldWrapper = (0, native_1.default)(react_native_1.View)(({ theme, color, disabled }) => {
    return Object.assign(Object.assign({ minHeight: 40, display: 'flex', flexDirection: 'row', columnGap: 10, borderRadius: theme.rounded.small, paddingHorizontal: theme.spacing.lg, borderWidth: 1, borderColor: theme.palette[color].dark, backgroundColor: theme.palette[color].light }, (color === 'secondary' && {
        backgroundColor: theme.palette.background.main,
    })), (disabled && {
        borderColor: theme.palette.disabled,
    }));
});
const TextFieldInput = native_1.default.TextInput(({ theme, size, disabled }) => {
    return Object.assign({ color: theme.palette.text.main, fontFamily: theme.fontFamily, paddingVertical: theme.spacing.md, fontSize: theme.fontSize[size] }, (disabled && {
        color: theme.palette.disabled,
    }));
});
const TextFieldIconContainer = (0, native_1.default)(react_native_1.View)(() => {
    return {
        justifyContent: 'center',
    };
});
const TextFieldText = native_1.default.Text(({ theme, color, size }) => {
    return {
        color: theme.palette[color].main,
        fontSize: theme.fontSize[size],
        fontFamily: theme.fontFamily,
    };
});
